@@ -1,24 +1,23 @@
 package Pod::ProjectDocs::CSS;
-
 use strict;
-use warnings;
-
-our $VERSION = '0.48_006';    # TRIAL VERSION
-
-use Moose;
-with 'Pod::ProjectDocs::File';
-
+use base qw/Pod::ProjectDocs::File/;
 use File::Basename;
+use File::Spec::Functions qw/abs2rel/;
 
-has 'default_name' => (
-    is      => 'ro',
-    isa     => 'Str',
-    default => 'podstyle.css',
-);
+__PACKAGE__->default_name('podstyle.css');
+__PACKAGE__->data( do{ local $/; <DATA> } );
+
+sub tag {
+	my $self = shift;
+	my $file = shift;
+	my($name, $path) = fileparse $file->path, qw/\.html/;
+	my $rel_path = abs2rel $self->path, $path;
+	return sprintf qq|<link rel="stylesheet" type="text/css" href="%s" />|, $rel_path;
+}
+
+1;
+__DATA__
 
-has 'data' => (
-    is      => 'ro',
-    default => <<'DATA',
 BODY, .logo { background: white; }
 
 BODY {
@@ -63,7 +62,7 @@ input { margin: 2px; }
   background: #006699;
   margin: 1ex 0;
   padding: 1px;
-}
+} 
 
 .menubar A {
   padding: 0.8ex;
@@ -340,6 +339,35 @@ table.dlsip     {
   list-style-type: none;
 }
 
+.faq DT {
+  font-size: 1.4em;
+  font-weight: bold;
+}
+
+.chmenu {
+  background: black;
+  color: red;
+  font: bold 1.1em Arial,Helvetica,sans-serif;
+  margin: 1ex auto;
+  padding: 0.5ex;
+}
+
+.chmenu TD {
+  padding: 0.2ex 1ex;
+}
+
+.chmenu A:link, .chmenu A:visited  {
+  background: transparent;
+  color: white;
+  text-decoration: none;
+}
+
+.chmenu A:hover {
+  background: transparent;
+  color: #ff6600;
+  text-decoration: underline;
+}
+
 .column {
   padding: 0.5ex 1ex;
   vertical-align: top;
@@ -368,18 +396,3 @@ table.dlsip     {
   border-top: none;
 }
 
-.search_highlight {
-	color: #ff6600;
-}
-DATA
-);
-
-sub relative_url {
-    my ( $self, $doc ) = @_;
-    my ( $name, $path ) = fileparse $doc->get_output_path, qw/\.html/;
-    my $relpath = File::Spec->abs2rel( $self->get_output_path, $path );
-    $relpath =~ s:\\:/:g if $^O eq 'MSWin32';
-    return $relpath;
-}
-
-1;
